<?php include_once 'codebase/hyperframe.php' ?>
<h1>Upgrading Hyperframe</h1>

<p><strong>Hyperframe has a compartmentalized directory structure, so as to allow easy replacement of individual code sections without having to replace the whole. This makes version upgrades a relatively straightforward task.&nbsp;</strong></p>

<p>Naturally, before any upgrade job, take a full backup of your website.</p>

<p>Hyperframe is supplied as a zip archive. Expand this into a suitable temporary location.</p>

<p><em>Important: Do NOT expand the archive into the same location as your existing website. </em></p>

<p>Rename the <strong><em>codebase</em></strong> directory in your existing site, for example to <strong><em>oldcodebase</em></strong>.</p>

<p>Copy or upload the <em>codebase</em> from the new version.</p>

<p>Replace the <strong><em>.htaccess</em></strong> file in the new codebase with the one from oldcodebase, so as to preserve any server-specific settings.</p>

<p>If you test at this stage, you will probably find that the site works.</p>

<p>Now, examine the<em> <strong>plugin</strong></em> directories of the new and old versions, and copy over any plugins which you are using, and which need upgrading. If you have customized any plugins, you might want to retain the configuration files and any custom code from these.</p>

<p>In <strong><em>sitecfg</em></strong>, it is not necessary to replace anything specific, but you might want to add to the existing siteini.php any new settings in the latest version. Don&#39;t worry about this if the new settings are not needed, since the defaults will apply for any absent values.</p>

<p>You might then need to check your <strong><em>frame</em></strong> php and css files for old and incompatible code, and for slight styling differences. But, these effects are usually quite small.</p>

<p>If all does not go well, then&nbsp; renaming oldcodebase back to codebase will in most cases fix that. That really is one of the excellent features of a file-based system - If it breaks, you replace the broken bits and it works again. No domino effect of missing database classes or the like to complicate and confuse matters, just files and files alone.</p>

<h3>Version 4</h3>

<p>The 4v upgrade process is a little more involved owing to the changes in core code. The above instructions still apply, however the following additional points need to be noted:</p>

<p>You site&#39;s frame needs to be relocated, into a subdirectory of frame/, eg&nbsp; frame/default The siteini.php reference to this should be the subdirectory name only, in this case &#39;default&#39; instead of &#39;frame&#39;</p>

<p>The frame.php head section must contain a call to the menu plugin, if standard menus are used:<br />
<strong>&nbsp; &lt;?php include_once plugin(&#39;menu&#39;) ?&gt;</strong><br />
Without this call, if system menus are used the page will fail to load partway through. It is best placed as the last line in the head section.</p>

<p>Needless to say, if the call is present then the menu plugin must also be copied to the plugin directory.</p>

<p>Optionally, the references to system.js, system.css, frame.js and frame.css can be removed from the frame.php head section, as these calls are now automated. Leaving them in will not prevent the site from loading, but will waste a small amount of server resources. The web icon reference is still required, if one is used.</p>

<p>At this stage the site should work OK, and the majority of the styling should be OK. The area likely to need some restyling is the menus.These now uses a common stylesheet for for top and side menus, plus one or two additions for dropdown styling. The old topmenu stylesheet section can be deleted from frame.css as it no longer has a function. To understand how the new menu styling works it is best to look at one of the example frames in the downloaded package. This change may involve some overhead in upgrading, but it unifies the menu styles and gives you a much wider scope for customization. It also means that you are not obliged to use the supplied menu system at all, if you don&#39;t want to.&nbsp;</p>

<h3>Earlier versions</h3>

<p>When upgrading from v2 to v3, a point to note is that individual pages may contain outdated methods of centering, captioning or aligning images. For example, placing an image inside a paragraph (or div or table) so that the paragraph&#39;s alignment applies to the image, is now a deprecated approach and any such instances should preferably be edited out.</p>

<h2>Upgrading CKEditor</h2>

<p>New versions of Hyperframe will typically include CKEditor upgrades. However, you might wish to upgrade your copy of CK in-between Hyperframe releases, to take advantage of any new features. This is also a fairly straightforward process.</p>

<p>Download the latest CKEditor from <a href="http://ckeditor.com/" target="_blank">ckeditor.com</a> -If you are not sure which to choose, get the version with all plugins.</p>

<p>On your website, rename codebase/<strong>ck</strong> to codebase/<strong>ckold</strong> (or whatever you like)</p>

<p>Create a new <strong>ck</strong> directory, and place the entire contents of the download in here.</p>

<p>In the new ck, navigate to codebase/ck/plugins.</p>

<p>Copy over the <em>hyperframe</em> plugin in its entirety from the old ck installation. (This is essential as Hyperframe will not run correctly without this plugin)</p>

<p>To retain the special image and link manipulation features of Hyperframe, rename or delete the image and link plugins, and copy the <em>image</em> and <em>link</em> plugins in their entirety, from codebase/ckold/plugins.</p>

<p>That should be all you need to get the new CKEditor running. You will not initially have any toolbar buttons for new features, since these need to be added to the Hyperframe toobar definition in the codebase/ck_config.js file. I&#39;ll just repeat that: <em>The configuration file to be modified is in Hyperframe&#39;s codebase</em>, <strong>not</strong> in the one in codebase/ck, which is unused and has no effect. It&#39;s done like this so that you can replace your CKEditor without having to worry about any internal config files.</p>

<p>Be careful when modifying ck_config.js, since the syntax is not quite like standard javascript, and locating trivial syntax errors such as a missing comma can be extremely hard without specialist tools. Best to back up your changes progressively as you proceed, then you can roll back to the last good version if an intractable problem arises.&nbsp;</p>
